@@ -1,5 +1,6 @@
 package CatalystX::Features::Backend;
-$CatalystX::Features::Backend::VERSION = '0.18';
+$CatalystX::Features::Backend::VERSION = '0.19';
+use Class::MOP ();
 use Moose;
 use Path::Class;
 use Carp;
@@ -21,13 +22,13 @@ sub init {
         my @features = $self->_find_features($home);
         foreach my $feature_path (@features) {
 
-            my $feature_class = $self->app->config->{feature_class}
+            my $feature_class = $self->config->{feature_class}
               || 'CatalystX::Features::Feature';
 
             $self->feature_class( $feature_class );
 
             # init feature
-			eval "require $feature_class";
+            Class::MOP::load_class( $feature_class );
             my $feature = $feature_class->new(
                 {
                     path    => "$feature_path",
@@ -93,7 +94,7 @@ sub _push_feature {
 
 sub config {
     my $self = shift;
-    return $self->app->config->{$CatalystX::Features::config_key};
+    return $self->app->config->{$CatalystX::Features::config_key} ||= {};
 }
 
 sub _array {
@@ -128,7 +129,7 @@ CatalystX::Features::Backend - All the dirty work is done here
 
 =head1 VERSION
 
-version 0.18
+version 0.19
 
 =head1 SYNOPSIS
 
